==> jc-1.4.0.tar.gz: gnu/xml/dom/Consumer.h <==
// public class gnu.xml.dom.Consumer

// class file dependencies
// @dep_class f5b0ebeeb54e38bb gnu_xml_dom_Consumer
// @dep_class dd1504d5138e45 gnu_xml_pipeline_DomConsumer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_DomConsumer

#include "gnu/xml/pipeline/DomConsumer.h"

#ifndef _JC_gnu_xml_dom_Consumer_H_
#define _JC_gnu_xml_dom_Consumer_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_Consumer$sub_refs	_jc_gnu_xml_dom_Consumer$sub_refs;
typedef struct _jc_gnu_xml_dom_Consumer$sub_nonrefs	_jc_gnu_xml_dom_Consumer$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_Consumer$refs	_jc_gnu_xml_dom_Consumer$refs;
typedef struct _jc_gnu_xml_dom_Consumer$nonrefs	_jc_gnu_xml_dom_Consumer$nonrefs;
typedef struct _jc_gnu_xml_dom_Consumer$object	_jc_gnu_xml_dom_Consumer$object;

typedef struct _jc_gnu_xml_dom_Consumer$fields_struct	_jc_gnu_xml_dom_Consumer$fields_struct;
typedef const struct _jc_gnu_xml_dom_Consumer$vmethods	_jc_gnu_xml_dom_Consumer$vmethods;
typedef const struct _jc_gnu_xml_dom_Consumer$vtable	_jc_gnu_xml_dom_Consumer$vtable;
typedef const struct _jc_gnu_xml_dom_Consumer$vtype	_jc_gnu_xml_dom_Consumer$vtype;

// Class fields structure
struct _jc_gnu_xml_dom_Consumer$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24xml__24dom__24DomDocument;
};
extern _jc_gnu_xml_dom_Consumer$fields_struct _jc_gnu_xml_dom_Consumer$class_fields;

// Constructors
extern void _jc_gnu_xml_dom_Consumer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_Consumer$object *);
extern void _jc_gnu_xml_dom_Consumer$method$_init$f55e1e8bd1cec8e3(_jc_env *, struct _jc_gnu_xml_dom_Consumer$object *, struct _jc_object *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_xml_dom_Consumer$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_xml_dom_Consumer$vmethods {
};

// Vtable
struct _jc_gnu_xml_dom_Consumer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_DomConsumer$vmethods	gnu_xml_pipeline_DomConsumer;
	_jc_gnu_xml_dom_Consumer$vmethods	gnu_xml_dom_Consumer;
};

// Vtype
struct _jc_gnu_xml_dom_Consumer$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_Consumer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_Consumer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_Consumer$refs {
    _jc_gnu_xml_dom_Consumer$sub_refs	gnu_xml_dom_Consumer;
    _jc_gnu_xml_pipeline_DomConsumer$sub_refs	gnu_xml_pipeline_DomConsumer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_Consumer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_Consumer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_DomConsumer$sub_nonrefs	gnu_xml_pipeline_DomConsumer;
    _jc_gnu_xml_dom_Consumer$sub_nonrefs	gnu_xml_dom_Consumer;
};

// Object instance structure
struct _jc_gnu_xml_dom_Consumer$object {
	_jc_gnu_xml_dom_Consumer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_Consumer$vtype	*vtype;
	_jc_gnu_xml_dom_Consumer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_Consumer$vtype _jc_gnu_xml_dom_Consumer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_Consumer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_Consumer$class_object;

#endif	/* _JC_gnu_xml_dom_Consumer_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/Consumer.h <==
// public class gnu.xml.dom.Consumer

// class file dependencies
// @dep_class f5b0ebeeb54e38bb gnu_xml_dom_Consumer
// @dep_class dd1504d5138e45 gnu_xml_pipeline_DomConsumer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_DomConsumer

#include "gnu/xml/pipeline/DomConsumer.h"

#ifndef _JC_gnu_xml_dom_Consumer_H_
#define _JC_gnu_xml_dom_Consumer_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_Consumer$sub_refs	_jc_gnu_xml_dom_Consumer$sub_refs;
typedef struct _jc_gnu_xml_dom_Consumer$sub_nonrefs	_jc_gnu_xml_dom_Consumer$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_Consumer$refs	_jc_gnu_xml_dom_Consumer$refs;
typedef struct _jc_gnu_xml_dom_Consumer$nonrefs	_jc_gnu_xml_dom_Consumer$nonrefs;
typedef struct _jc_gnu_xml_dom_Consumer$object	_jc_gnu_xml_dom_Consumer$object;

typedef struct _jc_gnu_xml_dom_Consumer$fields_struct	_jc_gnu_xml_dom_Consumer$fields_struct;
typedef const struct _jc_gnu_xml_dom_Consumer$vmethods	_jc_gnu_xml_dom_Consumer$vmethods;
typedef const struct _jc_gnu_xml_dom_Consumer$vtable	_jc_gnu_xml_dom_Consumer$vtable;
typedef const struct _jc_gnu_xml_dom_Consumer$vtype	_jc_gnu_xml_dom_Consumer$vtype;

// Class fields structure
struct _jc_gnu_xml_dom_Consumer$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24xml__24dom__24DomDocument;
};
extern _jc_gnu_xml_dom_Consumer$fields_struct _jc_gnu_xml_dom_Consumer$class_fields;

// Constructors
extern void _jc_gnu_xml_dom_Consumer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_Consumer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_Consumer$method$_init$f55e1e8bd1cec8e3(_jc_env *, struct _jc_gnu_xml_dom_Consumer$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_xml_dom_Consumer$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_dom_Consumer$vmethods {
};

// Vtable
struct _jc_gnu_xml_dom_Consumer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_DomConsumer$vmethods	gnu_xml_pipeline_DomConsumer;
	_jc_gnu_xml_dom_Consumer$vmethods	gnu_xml_dom_Consumer;
};

// Vtype
struct _jc_gnu_xml_dom_Consumer$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_Consumer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_Consumer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_Consumer$refs {
    _jc_gnu_xml_dom_Consumer$sub_refs	gnu_xml_dom_Consumer;
    _jc_gnu_xml_pipeline_DomConsumer$sub_refs	gnu_xml_pipeline_DomConsumer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_Consumer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_Consumer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_DomConsumer$sub_nonrefs	gnu_xml_pipeline_DomConsumer;
    _jc_gnu_xml_dom_Consumer$sub_nonrefs	gnu_xml_dom_Consumer;
};

// Object instance structure
struct _jc_gnu_xml_dom_Consumer$object {
	_jc_gnu_xml_dom_Consumer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_Consumer$vtype	*vtype;
	_jc_gnu_xml_dom_Consumer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_Consumer$vtype _jc_gnu_xml_dom_Consumer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_Consumer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_Consumer$class_object;

#endif	/* _JC_gnu_xml_dom_Consumer_H_ */
